@@ -23,7 +23,7 @@ def authorize(security_group, port, realm, port_end_range=False):
     # Setup single ports, unless noted
     if not port_end_range:
         port_end_range = port
-    
+
     # Catch errors from overpopulating
     try:
         # Open ports publicly
@@ -40,6 +40,20 @@ def authorize(security_group, port, realm, port_end_range=False):
         # Continue since ports were probably trying to be overwritten
         pass
 
+def deauthorize(security_group, port, port_end_range=False):
+
+    # Setup single ports, unless noted
+    if not port_end_range:
+        port_end_range = port
+
+    # Catch errors from overpopulating
+    try:
+        # Open ports publicly
+        security_group.revoke('tcp', port, port_end_range, '0.0.0.0/0')
+    except boto.exception.EC2ResponseError:
+        # Continue since ports were probably trying to be overwritten
+        pass
+
 def print_boto_error():
     """Attempts to extract the XML from boto errors to present plain errors with no stacktraces."""
 
@@ -126,37 +140,40 @@ def create_cluster(aws_access_key_id, aws_secret_access_key, reservation_size, i
     # Create the DataStax security group if it doesn't exist
     if not ds_security_group:
         ds_security_group = conn.create_security_group('DataStax', 'Security group for running DataStax products')
-    
+
     # Ensure all Security settings are active
     print "Configuring ports..."
-    authorize(ds_security_group, 22, 'public')
-    authorize(ds_security_group, 9160, 'public')
-    authorize(ds_security_group, 8012, 'public')
-    authorize(ds_security_group, 50030, 'public')
-    authorize(ds_security_group, 50060, 'public')
-    authorize(ds_security_group, 8983, 'public')
-    authorize(ds_security_group, 8888, 'public')
 
-    authorize(ds_security_group, 7000, 'private')
-    authorize(ds_security_group, 7199, 'private')
-    authorize(ds_security_group, 8983, 'private')
-    authorize(ds_security_group, 9290, 'private')
-    authorize(ds_security_group, 61621, 'private')
-    authorize(ds_security_group, 1024, 'private', 65535)
-    authorize(ds_security_group, 50031, 'private')
-    authorize(ds_security_group, 61620, 'private')
+    # Remove previous security risks made public
+    deauthorize(ds_security_group, 9160)
+
+    authorize(ds_security_group, 22, 'public') # SSH
+    authorize(ds_security_group, 8012, 'public') # Hadoop Job Tracker client port
+    authorize(ds_security_group, 8888, 'public') # OpsCenter website port
+    authorize(ds_security_group, 8983, 'public') # Portfolio and Solr default port
+    authorize(ds_security_group, 50030, 'public') # Hadoop Job Tracker website port
+    authorize(ds_security_group, 50060, 'public') # Hadoop Task Tracker website port
+
+    authorize(ds_security_group, 7000, 'private') # Cassandra intra-node port
+    authorize(ds_security_group, 7199, 'private') # JMX initial port
+    authorize(ds_security_group, 9160, 'private') # Cassandra client port
+    authorize(ds_security_group, 9290, 'private') # Hadoop Job Tracker Thrift port
+    authorize(ds_security_group, 50031, 'private') # Hadoop job tracker port
+    authorize(ds_security_group, 61620, 'private') # OpsCenter Agent port
+    authorize(ds_security_group, 61621, 'private') # OpsCenter Agent port
+    authorize(ds_security_group, 1024, 'private', 65535) # JMX reconnection ports
 
     try:
         # Create the EC2 cluster
         print 'Launching cluster...'
         start_time = time.time()
         try:
-            reservation = conn.run_instances(image, 
-                                             min_count=reservation_size, 
-                                             max_count=reservation_size, 
-                                             instance_type=instance_type, 
-                                             key_name=key_pair, 
-                                             placement=placement, 
+            reservation = conn.run_instances(image,
+                                             min_count=reservation_size,
+                                             max_count=reservation_size,
+                                             instance_type=instance_type,
+                                             key_name=key_pair,
+                                             placement=placement,
                                              security_groups=['DataStax'], user_data=user_data)
         except boto.exception.EC2ResponseError:
             print_boto_error()
@@ -182,7 +199,7 @@ def create_cluster(aws_access_key_id, aws_secret_access_key, reservation_size, i
     except (Exception, KeyboardInterrupt, EOFError) as err:
         print "\n\nERROR: Tags were never applied to started instances!!! Make sure you TERMINATE instances here:"
         print "    https://console.aws.amazon.com/ec2/home?region=us-east-1#s=Instances\n"
-        
+
         # Ensure the user acknowledges pricing danger
         while True:
             try:
